==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>A autenticação expirou</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>O disco está ocupado; impossível desmontá-lo</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>O disco está ocupado; impossível ejetá-lo</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>O dispositivo está ocupado; impossível ejetá-lo</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>O dispositivo está ocupado; impossível removê-lo</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>Volume de %1</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>O dispositivo não foi removido com segurança</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Clique em &quot;Remover com segurança&quot; e então desconecte-o na próxima vez</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation type="vanished">O dispositivo está ocupado; impossível ejetá-lo</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation type="vanished">O dispositivo está ocupado; impossível removê-lo</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Impossível desmontar o dispositivo</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>O disco foi montado pelo usuário &quot;%1&quot;; e você não pode desmontá-lo.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Impossível encontrar o dispositivo montado</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Dispositivos</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disco</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Ejetar tudo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>O dispositivo foi removido com segurança</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Acesso negado</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Você não tem permissão para acessar esta pasta</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Verificando o dispositivo, parar?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.6.4.orig.tar.xz: dde-file-manager-5.6.4/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>A autenticação expirou</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>O disco está ocupado; impossível desmontá-lo</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>O disco está ocupado; impossível ejetá-lo</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>O dispositivo está ocupado; impossível ejetá-lo</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>O dispositivo está ocupado; impossível removê-lo</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>Volume de %1</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>O dispositivo não foi removido com segurança</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Clique em &quot;Remover com segurança&quot; e então desconecte-o na próxima vez</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Impossível desmontar o dispositivo</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>O disco foi montado pelo usuário &quot;%1&quot;; e você não pode desmontá-lo.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Impossível encontrar o dispositivo montado</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Dispositivos</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disco</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Ejetar tudo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>O dispositivo foi removido com segurança</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Acesso negado</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Você não tem permissão para acessar esta pasta</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Verificando o dispositivo, parar?</translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>Parar</translation>
    </message>
</context>
</TS>
